@@ -34,13 +34,13 @@ import email.mime.multipart
 import email.mime.text
 import email.mime.image
 
-from bs_lib.Pod   import Pod
+from bs_lib import Pod
 
-from bs_loco.db   import tMsg
+from bs_loco.db.tables import tMsg
 
 from .provider_email import ProviderEmail
 
-from bs_lib  import Common
+from bs_lib  import common
 
 
 class SmtpEmail(ProviderEmail):
@@ -77,14 +77,14 @@ class SmtpEmail(ProviderEmail):
         """
         ProviderEmail.initialize(self, pod, dao, cfg)
 
-        Common.readDict(self._cfg, 'host',        str)
-        Common.readDict(self._cfg, 'port',        int)
-        Common.readDict(self._cfg, 'username',    str)
-        Common.readDict(self._cfg, 'passwd',      str)
-        Common.readDict(self._cfg, 'from',        str)
-        Common.readDict(self._cfg, 'ssl',         bool)
-        Common.readDict(self._cfg, 'tls',         bool)
-        Common.readDict(self._cfg, 'timeout',     float)
+        common.read_dict(self._cfg, 'host',        str)
+        common.read_dict(self._cfg, 'port',        int)
+        common.read_dict(self._cfg, 'username',    str)
+        common.read_dict(self._cfg, 'passwd',      str)
+        common.read_dict(self._cfg, 'from',        str)
+        common.read_dict(self._cfg, 'ssl',         bool)
+        common.read_dict(self._cfg, 'tls',         bool)
+        common.read_dict(self._cfg, 'timeout',     float)
 
 
     def _logoff(self):
